==> protonsdk-0.7.0-sources.jar: com/metallicus/protonsdk/model/ProtonESR.kt <==
/*
 * Copyright (c) 2020 Proton Chain LLC, Delaware
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.metallicus.protonsdk.model

import com.greymass.esr.ResolvedSigningRequest
import com.greymass.esr.SigningRequest

class ProtonESR(
	val requestKey: String,
	val signingAccount: ChainAccount,
	val signingRequest: SigningRequest,
	val originESRUrlScheme: String,
	val requestAccount: Account? = null,
	val returnPath: String? = "",
	val resolvedSigningRequest: ResolvedSigningRequest? = null//,
	//val actions: List<ProtonESRAction>
) {
	fun getRequestAccountDisplayName(): String {
		return requestAccount?.accountContact?.getDisplayName() ?: "Unknown Requester"
	}
}

==> protonsdk-0.7.1-sources.jar: com/metallicus/protonsdk/model/ProtonESR.kt <==
/*
 * Copyright (c) 2020 Proton Chain LLC, Delaware
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.metallicus.protonsdk.model

import com.greymass.esr.ResolvedSigningRequest
import com.greymass.esr.SigningRequest

class ProtonESR(
	val requestKey: String,
	val signingAccount: ChainAccount,
	val signingRequest: SigningRequest,
	val originESRUrlScheme: String,
	val requestAccount: Account? = null,
	val returnPath: String? = "",
	var resolvedSigningRequest: ResolvedSigningRequest? = null//,
	//val actions: List<ProtonESRAction>
) {
	fun getRequestAccountDisplayName(): String {
		return requestAccount?.accountContact?.getDisplayName() ?: "Unknown Requester"
	}
}
